============================
Unit Helper Module
============================
.. currentmodule:: stravalib.unithelper

The `unithelper` module provides helper utility
to convert various units.

Summary Functions
------------------

.. autosummary::
   :toctree: api/

   is_quantity_type
   c2f


Summary Classes
----------------
.. autosummary::
   :toctree: api/

   UnitsQuantity
   Quantity
   UnitConverter
